## 2.2.0.20250318 (2025-03-18)

Fix various argument of extension modules (#13651)

* Mark various positional-only arguments: These are all positional-only
  arguments in C code using the `METH_O` flag.
* Remove various `*args, **kwargs` arguments that are using the
  `METH_NOARGS` flag in C.

## 2.2.0.20241221 (2024-12-21)

Update to mypy 1.14 (#13272)

## 2.2.0.20240911 (2024-09-11)

mysqlclient: Annotate Connect() return type (#12633)

## 2.2.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 2.2.0.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 2.2.0.0 (2023-06-23)

Bump mysqlclient to 2.2 (#10353)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 2.1.5.7 (2023-03-27)

Add defaults for third-party stubs M-O (#9956)

## 2.1.5.6 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 2.1.5.5 (2023-02-22)

Update `Unused` parameters in `stubs/` (#9704)

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 2.1.5.4 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 2.1.5.3 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 2.1.5.2 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 2.1.5.1 (2022-11-23)

Mark first argument of `__[get|set|del]attr__` as `str` (#9245)

## 2.1.5 (2022-07-26)

mysqlclient.connection: add missing type hints (#8393)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

Add type hints to mysqlclient.times (#8392)

## 2.1.4 (2022-07-25)

Annotate `mysqlclient.release.version_info` (#8391)

## 2.1.3 (2022-07-24)

`mysqlclient`: Annotate types of exceptions in `Connection` class (#8382)

## 2.1.2 (2022-07-24)

Add return type to MySQLdb.Connection.__enter__ (#8381)

This pull request adds the return type, as seen in the link below, to the `mysqlclient.MySQLdb.connections:Connection.__enter__`
https://github.com/PyMySQL/mysqlclient/blob/main/MySQLdb/connections.py#L230-L231

## 2.1.1 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 2.1.0 (2022-06-21)

Bump mysqlclient to 2.1.* (#8116)

## 2.0.5 (2022-02-22)

Correct several positional-only differences in third-party stubs (#7352)

## 2.0.3 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.0.2 (2021-12-17)

Use stubtest 0.920 (#6589)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Sebastian Rittau <srittau@rittau.biz>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.0.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

